EXPORTS
	?Version@CHelloTraceInterface@@SA?AVTVersion@@XZ @ 1 NONAME ; class TVersion CHelloTraceInterface::Version(void)
	?NewLC@CHelloTraceInterface@@SAPAV1@XZ @ 2 NONAME ; class CHelloTraceInterface * CHelloTraceInterface::NewLC(void)
	?JustTypes@HelloTraceExample@@SAXXZ @ 3 NONAME ; void HelloTraceExample::JustTypes(void)
	?Interface@HelloTraceExample@@SAXXZ @ 4 NONAME ; void HelloTraceExample::Interface(void)
	?FnEntryExit@HelloTraceExample@@SAXXZ @ 5 NONAME ; void HelloTraceExample::FnEntryExit(void)
	?ResetString@CHelloTraceInterface@@QAEXXZ @ 6 NONAME ; void CHelloTraceInterface::ResetString(void)
	?AddCharL@CHelloTraceInterface@@QAEXABVTChar@@@Z @ 7 NONAME ; void CHelloTraceInterface::AddCharL(class TChar const &)
	?PanicTrace@HelloTraceExample@@SAXXZ @ 8 NONAME ; void HelloTraceExample::PanicTrace(void)
	??1CHelloTraceInterface@@UAE@XZ @ 9 NONAME ; CHelloTraceInterface::~CHelloTraceInterface(void)
	?String@CHelloTraceInterface@@QBE?BVTPtrC16@@XZ @ 10 NONAME ; class TPtrC16 const CHelloTraceInterface::String(void) const
	?RemoveLast@CHelloTraceInterface@@QAEXXZ @ 11 NONAME ; void CHelloTraceInterface::RemoveLast(void)
	?NewL@CHelloTraceInterface@@SAPAV1@XZ @ 12 NONAME ; class CHelloTraceInterface * CHelloTraceInterface::NewL(void)

